==============
Administration
==============

Search provides the data crunching required to index strings and provide search results.

The search index is loaded by other plugins, the search plugin then indexes the search
terms and results, then provides users with a UI to search and view the data.

APIs are also available in the Peek Desktop and Peek Mobile services to for other plugins
to use the search.


.. toctree::
    :maxdepth: 3
    :caption: Contents:

    overview
    status/status
    admin_tasks/admin_tasks

